//
//  GameScene.swift
//  XP6S2016
//
//  Created by Zdzisław Sroczyński on 28.11.2016.
//  Copyright © 2016 Zdzisław Sroczyński. All rights reserved.
//

import SpriteKit

class GameScene: SKScene {
    
    
    fileprivate var label : SKLabelNode?
    fileprivate var spinnyNode : SKShapeNode?
    fileprivate var mysprite : SKSpriteNode?
    
    class func newGameScene() -> GameScene {
        // Load 'GameScene.sks' as an SKScene.
        guard let scene = SKScene(fileNamed: "GameScene") as? GameScene else {
            print("Failed to load GameScene.sks")
            abort()
        }
        
        // Set the scale mode to scale to fit the window
        scene.scaleMode = .aspectFill
        
        return scene
    }
    
    func setUpScene() {
        // Get label node from scene and store it for use later
        self.label = self.childNode(withName: "//helloLabel") as? SKLabelNode
        
        if let label = self.label {
            label.alpha = 0.0
            label.run(SKAction.fadeIn(withDuration: 2.0))
        }
        
        self.mysprite = self.childNode(withName: "//mojSKSpriteNode") as? SKSpriteNode
        
        
        if let mysprite = self.mysprite {
            mysprite.alpha = 0.0
            mysprite.run(SKAction.fadeIn(withDuration: 2.0))
            mysprite.run(SKAction.repeatForever(SKAction.rotate(byAngle: CGFloat(M_PI), duration: 1)))
        }
        
        let drugisprite = SKSpriteNode(imageNamed: "mojelogo")
        drugisprite.name = "mojelogoijuz"
        drugisprite.zPosition = 1
        drugisprite.position = CGPoint(x: 0, y: 150)
        drugisprite.size = CGSize(width: 5, height: 5)
        drugisprite.run(SKAction.fadeIn(withDuration: 2.0))
        drugisprite.run(SKAction.scale(by: 50, duration: 15))
        self.addChild(drugisprite)
        
        // Create shape node to use during mouse interaction
        let w = (self.size.width + self.size.height) * 0.05
        self.spinnyNode = SKShapeNode(rectOf: CGSize.init(width: w, height: w), cornerRadius: w * 0.4)
        //init?
        if let spinnyNode = self.spinnyNode {
            spinnyNode.lineWidth = 6.0
            spinnyNode.run(SKAction.repeatForever(SKAction.rotate(byAngle: CGFloat(M_PI), duration: 1)))
            spinnyNode.run(SKAction.sequence([SKAction.wait(forDuration: 0.5),
                                              SKAction.fadeOut(withDuration: 0.5),
                                              SKAction.removeFromParent()]))
            
            
        }
    }
    
    
    override func didMove(to view: SKView) {
        self.setUpScene()
    }


    func makeSpinny(at pos: CGPoint, color: SKColor) {
        if let spinny = self.spinnyNode?.copy() as! SKShapeNode? {
            spinny.position = pos
            spinny.strokeColor = color
            self.addChild(spinny)
        }
    }
    
    override func update(_ currentTime: TimeInterval) {
        // Called before each frame is rendered
    }
}

extension GameScene {

    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        if let label = self.label {
            label.run(SKAction(named: "Pulse")!, withKey: "fadeInOut")
            //init?
            
        }
        
        for t in touches {
            self.makeSpinny(at: t.location(in: self), color: SKColor.green)
        }
        
        let touch:UITouch = touches.first! as UITouch
        let positionInScene = touch.location(in: self)
        let touchedNode = self.atPoint(positionInScene)
        
        if let name = touchedNode.name
        {
            if name == "mojelogoijuz"
            {
                let logousun = self.childNode(withName: "//mojelogoijuz") as? SKSpriteNode
                logousun?.removeFromParent()
            }
        }
        
    }
    
    override func touchesMoved(_ touches: Set<UITouch>, with event: UIEvent?) {
        for t in touches {
            self.makeSpinny(at: t.location(in: self), color: SKColor.blue)
        }
    }
    
    override func touchesEnded(_ touches: Set<UITouch>, with event: UIEvent?) {
        for t in touches {
            self.makeSpinny(at: t.location(in: self), color: SKColor.red)
        }
    }
    
    override func touchesCancelled(_ touches: Set<UITouch>, with event: UIEvent?) {
        for t in touches {
            self.makeSpinny(at: t.location(in: self), color: SKColor.red)
        }
    }
    
   
}




